==> kutty-0.5.0.tgz: package/src/dialog.js <==
module.exports = Dialog = () => ({
  ".dialog": {
    "--tw-bg-opacity": ["1", "0.5"],
    backgroundColor: "rgba(0, 0, 0, var(--tw-bg-opacity))",
    cursor: "pointer",
    height: "100%",
    outline: "2px solid transparent",
    outlineOffset: "2px",
    overflow: "hidden",
    position: "fixed",
    top: "0px",
    right: "0px",
    bottom: "0px",
    left: "0px",
    width: "100%",
    zIndex: 40,
    transitionProperty: "background-color, border-color, color, fill, stroke, opacity, box-shadow, transform",
    transitionTimingFunction: "cubic-bezier(0.4, 0, 0.2, 1)",
    transitionDuration: "150ms",
  },
  ".dialog-content": {
    "--tw-bg-opacity": "1",
    backgroundColor: "rgba(255, 255, 255, var(--tw-bg-opacity))",
    borderRadius: "0px",
    cursor: "auto",
    display: "flex",
    flexDirection: "column",
    height: "100vh",
    marginTop: "0px",
    marginBottom: "0px",
    marginLeft: "auto",
    marginRight: "auto",
    position: "relative",
    zIndex: 50,
  },
  ".dialog.dialog-full .dialog-content": {
    borderRadius: "0px",
    height: "100vh",
    marginTop: "0px",
    marginBottom: "0px",
    maxHeight: "100vh",
    width: "100%",
  },
  ".dialog-header": {
    "--tw-border-opacity": "1",
    borderColor: "rgba(241, 245, 249, var(--tw-border-opacity))",
    borderBottomWidth: "1px",
    display: "flex",
    alignItems: "center",
    justifyContent: "space-between",
    paddingTop: "0.75rem",
    paddingBottom: "0.75rem",
    paddingLeft: "1rem",
    paddingRight: "1rem",
  },
  ".dialog-body": {
    flex: "1 1 auto",
    overflowY: "auto",
    padding: "1rem",
    position: "relative",
  },
  ".prose .dialog-content img": { marginTop: "0px", marginBottom: "0px" },
  ".dialog-footer": {
    "--tw-bg-opacity": "1",
    backgroundColor: "rgba(241, 245, 249, var(--tw-bg-opacity))",
    borderBottomRightRadius: "0.25rem",
    borderBottomLeftRadius: "0.25rem",
    display: "flex",
    alignItems: "center",
    justifyContent: "flex-end",
    padding: "0.75rem",
  },
  ".dialog-footer .btn + .btn": { marginLeft: "0.25rem" },
  ".scrollbar-measure": {
    overflow: "scroll",
    position: "absolute",
    top: "-9999px",
    width: "50px",
    height: "50px",
  },
  // Drawer
  ".dialog.active .drawer-content": { "--tw-translate-x": "0px !important" },
  ".dialog:not(.dialog-right) .drawer-content": {
    marginRight: "auto",
    transformOrigin: "left",
    "--tw-translate-x": "-100%",
  },
  ".dialog-right .drawer-content": {
    marginLeft: "auto",
    transformOrigin: "right",
    "--tw-translate-x": "100%",
  },
  ".drawer-content": {
    "--tw-bg-opacity": "1",
    backgroundColor: "rgba(255, 255, 255, var(--tw-bg-opacity))",
    cursor: "auto",
    display: "flex",
    flexDirection: "column",
    height: ["100%", "100vh"],
    marginTop: "0px",
    marginBottom: "0px",
    maxHeight: ["100%", "100vh"],
    minHeight: ["100%", "100vh"],
    position: "relative",
    width: "83.333333%",
    zIndex: 50,
    "--tw-translate-x": "0",
    "--tw-translate-y": "0",
    "--tw-rotate": "0",
    "--tw-skew-x": "0",
    "--tw-skew-y": "0",
    "--tw-scale-x": "1",
    "--tw-scale-y": "1",
    transform:
      "translateX(var(--tw-translate-x)) translateY(var(--tw-translate-y)) rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y))",
    transitionProperty: "background-color, border-color, color, fill, stroke, opacity, box-shadow, transform",
    transitionTimingFunction: "cubic-bezier(0.4, 0, 0.2, 1)",
    transitionDuration: "150ms",
  },
  ".dialog.dialog-full .drawer-content": {
    height: "100vh",
    marginTop: "0px",
    marginBottom: "0px",
    maxHeight: "100vh",
    width: "100%",
  },
  // Screen Sizes
  "@media (min-width: 640px)": {
    ".dialog-content": {
      borderRadius: "0.25rem",
      height: "auto",
      marginTop: "2rem",
      marginBottom: "2rem",
      width: "83.333333%",
      maxHeight: "calc(100% - 4rem)",
    },
  },
  "@media (min-width: 768px)": {
    ".dialog-content, .drawer-content": { width: "80%" },
  },
  "@media (min-width: 1024px)": {
    ".dialog-content": { width: "50%" },
    ".dialog.dialog-sm .dialog-content": { width: "25%" },
    ".dialog.dialog-lg .dialog-content": { width: "80%" },
    ".drawer-content": { width: "25%" },
    ".dialog.dialog-sm .drawer-content": { width: "16.666667%" },
    ".dialog.dialog-lg .drawer-content": { width: "66.666667%" },
  },
});

==> kutty-0.5.2.tgz: package/src/dialog.js <==
module.exports = Dialog = () => ({
  ".dialog": {
    "--tw-bg-opacity": ["1", "0.5"],
    backgroundColor: "rgba(0, 0, 0, var(--tw-bg-opacity))",
    cursor: "pointer",
    height: "100%",
    outline: "2px solid transparent",
    outlineOffset: "2px",
    overflow: "hidden",
    position: "fixed",
    top: "0px",
    right: "0px",
    bottom: "0px",
    left: "0px",
    width: "100%",
    zIndex: 40,
    transitionProperty:
      "background-color, border-color, color, fill, stroke, opacity, box-shadow, transform",
    transitionTimingFunction: "cubic-bezier(0.4, 0, 0.2, 1)",
    transitionDuration: "150ms",
  },
  ".dialog-content": {
    "--tw-bg-opacity": "1",
    backgroundColor: "rgba(255, 255, 255, var(--tw-bg-opacity))",
    borderRadius: "0px",
    cursor: "auto",
    display: "flex",
    flexDirection: "column",
    height: "100vh",
    marginTop: "0px",
    marginBottom: "0px",
    marginLeft: "auto",
    marginRight: "auto",
    position: "relative",
    zIndex: 50,
  },
  ".dialog.dialog-full .dialog-content": {
    borderRadius: "0px",
    height: "100vh",
    marginTop: "0px",
    marginBottom: "0px",
    maxHeight: "100vh",
    width: "100%",
  },
  ".dialog-header": {
    "--tw-border-opacity": "1",
    borderColor: "rgba(241, 245, 249, var(--tw-border-opacity))",
    borderBottomWidth: "1px",
    display: "flex",
    alignItems: "center",
    justifyContent: "space-between",
    paddingTop: "0.75rem",
    paddingBottom: "0.75rem",
    paddingLeft: "1rem",
    paddingRight: "1rem",
  },
  ".dialog-body": {
    flex: "1 1 auto",
    overflowY: "auto",
    padding: "1rem",
    position: "relative",
  },
  ".prose .dialog-content img": { marginTop: "0px", marginBottom: "0px" },
  ".dialog-footer": {
    "--tw-bg-opacity": "1",
    backgroundColor: "rgba(241, 245, 249, var(--tw-bg-opacity))",
    borderBottomRightRadius: "0.25rem",
    borderBottomLeftRadius: "0.25rem",
    display: "flex",
    alignItems: "center",
    justifyContent: "flex-end",
    padding: "0.75rem",
  },
  ".dialog-footer .btn + .btn": { marginLeft: "0.25rem" },
  ".scrollbar-measure": {
    overflow: "scroll",
    position: "absolute",
    top: "-9999px",
    width: "50px",
    height: "50px",
  },
  // Drawer
  ".dialog.active .drawer-content": { "--tw-translate-x": "0px !important" },
  ".dialog:not(.dialog-right) .drawer-content": {
    marginRight: "auto",
    transformOrigin: "left",
    "--tw-translate-x": "-100%",
  },
  ".dialog-right .drawer-content": {
    marginLeft: "auto",
    transformOrigin: "right",
    "--tw-translate-x": "100%",
  },
  ".drawer-content": {
    "--tw-bg-opacity": "1",
    backgroundColor: "rgba(255, 255, 255, var(--tw-bg-opacity))",
    cursor: "auto",
    display: "flex",
    flexDirection: "column",
    height: ["100%", "100vh"],
    marginTop: "0px",
    marginBottom: "0px",
    maxHeight: ["100%", "100vh"],
    minHeight: ["100%", "100vh"],
    position: "relative",
    width: "83.333333%",
    zIndex: 50,
    "--tw-translate-x": "0",
    "--tw-translate-y": "0",
    "--tw-rotate": "0",
    "--tw-skew-x": "0",
    "--tw-skew-y": "0",
    "--tw-scale-x": "1",
    "--tw-scale-y": "1",
    transform:
      "translateX(var(--tw-translate-x)) translateY(var(--tw-translate-y)) rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y))",
    transitionProperty:
      "background-color, border-color, color, fill, stroke, opacity, box-shadow, transform",
    transitionTimingFunction: "cubic-bezier(0.4, 0, 0.2, 1)",
    transitionDuration: "150ms",
  },
  ".dialog.dialog-full .drawer-content": {
    height: "100vh",
    marginTop: "0px",
    marginBottom: "0px",
    maxHeight: "100vh",
    width: "100%",
  },
  // Screen Sizes
  "@media (min-width: 640px)": {
    ".dialog-content": {
      borderRadius: "0.25rem",
      height: "auto",
      marginTop: "2rem",
      marginBottom: "2rem",
      width: "83.333333%",
      maxHeight: "calc(100% - 4rem)",
    },
  },
  "@media (min-width: 768px)": {
    ".dialog-content, .drawer-content": { width: "80%" },
  },
  "@media (min-width: 1024px)": {
    ".dialog-content": { width: "50%" },
    ".dialog.dialog-sm .dialog-content": { width: "25%" },
    ".dialog.dialog-lg .dialog-content": { width: "80%" },
    ".drawer-content": { width: "25%" },
    ".dialog.dialog-sm .drawer-content": { width: "16.666667%" },
    ".dialog.dialog-lg .drawer-content": { width: "66.666667%" },
  },
  // iOS 100vh Fix
  "@supports (-webkit-touch-callout:none)": {
    ".drawer-content": {
      height: "-webkit-fill-available",
      maxHeight: "-webkit-fill-available",
      minHeight: "-webkit-fill-available",
    },
    ".dialog-content": {
      height: "-webkit-fill-available",
    },
    ".dialog.dialog-full .dialog-content": {
      height: "-webkit-fill-available",
      maxHeight: "-webkit-fill-available",
    },
    ".dialog.dialog-full .drawer-content": {
      height: "-webkit-fill-available",
      maxHeight: "-webkit-fill-available",
    },
  },
});
